@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Array;
-$List::Objects::WithUtils::Array::VERSION = '2.017002';
+$List::Objects::WithUtils::Array::VERSION = '2.018001';
 use strictures 1;
 
 require Role::Tiny;
@@ -10,8 +10,18 @@ Role::Tiny->apply_roles_to_package( __PACKAGE__,
    /
 );
 
-use Exporter 'import';
+use Exporter ();
 our @EXPORT = 'array';
+
+sub import {
+  my $pkg = caller;
+  { no strict 'refs';
+    ${"${pkg}::a"} = ${"${pkg}::a"};
+    ${"${pkg}::b"} = ${"${pkg}::b"};
+  }
+  goto &Exporter::import
+}
+
 sub array { __PACKAGE__->new(@_) }
 
 1;
